{% load bootstrap %}
{% load i18n %}

<div class="panel panel-default">
    <div class="panel-heading">
        <div class="panel-title">
            {% translate "After Action Report" %}
        </div>
    </div>

    <div class="panel-body">
        <form action="{% url 'aasrp:edit_srp_link' srp_code %}" method="post">
            {% csrf_token %}

            <fieldset class="aa-srp-edit-link-form col-md-6 col-md-offset-3">
                {{ form|bootstrap }}

                <div class="form-group aasrp-form-group text-right clearfix">
                    <button class="btn btn-primary" type="submit">
                        {% translate "Add/Change AAR Link" %}
                    </button>
                </div>
            </fieldset>
        </form>
    </div>
</div>
