{% load i18n %}

<div class="panel panel-default">
    <div class="panel-heading">
        <div class="panel-title">
            {% translate "SRP Requests" %}
        </div>
    </div>

    <div class="panel-body">
        <div class="table-responsive">
            <table class="table table-striped table-aasrp table-srp-requests table-vertical-middle" id="tab_aasrp_srp_requests" style="width: 100%;">
                <thead>
                    <tr>
                        <th>{% translate "Request Time" %}</th>
                        <th>{% translate "Requestor" %}</th>
                        <th>{% translate "Character" %}</th>
                        <th>{% translate "Request Code" %}</th>
                        <th>{% translate "Ship" %}</th>
                        <th>{% translate "ISK Lost" %}</th>
                        <th>
                            {% translate "SRP Payout" %}
                            <i class="fas fa-question-circle fa-fw" data-tooltip="payout-hint" title="{% translate 'Click on the value to edit, Enter to save, ESC to cancel.' %}"></i>
                        </th>
                        <th>{% translate "Status" %}</th>
                        <th>{% translate "Actions" %}</th>
                    </tr>
                </thead>

                <tbody></tbody>
            </table>
        </div>
    </div>
</div>
